package com.srs.teacher.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.teacher.domain.SysTeacherTraining;

/**
 * trainingService接口
 *
 * @author srs
 * @date 2024-05-29
 */
public interface ISysTeacherTrainingService extends IService<SysTeacherTraining> {
    /**
     * 查询training
     *
     * @param trainingId training主键
     * @return training
     */
    public SysTeacherTraining selectSysTeacherTrainingByTrainingId(Long trainingId);

    /**
     * 查询training列表
     *
     * @param sysTeacherTraining training
     * @return training集合
     */
    List<SysTeacherTraining> selectSysTeacherTrainingList(SysTeacherTraining sysTeacherTraining);

    /**
     * 新增training
     *
     * @param sysTeacherTraining training
     * @return 结果
     */
    int insertSysTeacherTraining(SysTeacherTraining sysTeacherTraining);

    /**
     * 修改training
     *
     * @param sysTeacherTraining training
     * @return 结果
     */
    int updateSysTeacherTraining(SysTeacherTraining sysTeacherTraining);

    /**
     * 批量删除training
     *
     * @param trainingIds 需要删除的training主键集合
     * @return 结果
     */
    int deleteSysTeacherTrainingByTrainingIds(Long[] trainingIds);

    /**
     * 删除training信息
     *
     * @param trainingId training主键
     * @return 结果
     */
    int deleteSysTeacherTrainingByTrainingId(Long trainingId);
}
